.w-form-formrecaptcha {
    margin-bottom: 8px;
}

.w-layout-blockcontainer {
    max-width: 940px;
    margin-left: auto;
    margin-right: auto;
    display: block;
}

@media screen and (max-width: 991px) {
    .w-layout-blockcontainer {
        max-width: 728px;
    }
}

@media screen and (max-width: 767px) {
    .w-layout-blockcontainer {
        max-width: none;
    }
}

h1 {
    color: #343f52;
    letter-spacing: -.01rem;
    margin-top: 0;
    margin-bottom: 20px;
    font-size: 30px;
    font-weight: 600;
    line-height: 1.35;
}

h2 {
    color: #343f52;
    letter-spacing: -.01rem;
    margin-top: 0;
    margin-bottom: 15px;
    font-size: 26px;
    font-weight: 600;
    line-height: 1.35;
}

h3 {
    color: #343f52;
    letter-spacing: -.01rem;
    margin-top: 0;
    margin-bottom: 10px;
    font-size: 21px;
    font-weight: 600;
    line-height: 1.4;
}

h4 {
    color: #343f52;
    letter-spacing: -.01rem;
    margin-top: 0;
    margin-bottom: 10px;
    font-size: 19px;
    font-weight: 600;
    line-height: 1.45;
}

h5 {
    color: #343f52;
    letter-spacing: -.01rem;
    margin-top: 0;
    margin-bottom: 10px;
    font-size: 18px;
    font-weight: 600;
    line-height: 1.5;
}

h6 {
    color: #343f52;
    letter-spacing: -.01rem;
    margin-top: 0;
    margin-bottom: 10px;
    font-size: 16px;
    font-weight: 600;
    line-height: 1.55;
}

p {
    margin-bottom: 25px;
}

a {
    text-decoration: none;
}

/* TODO: Move styling from global definitions to CSS class compositions */
a:hover:not(.tps-btn):not(.btn):not(.cta-primary):not(.cta-secondary) {
    color: #605dba;
    text-decoration: none;
    border-bottom-color: #ccf2df;
}

ul {
    margin-top: 0;
    margin-bottom: 25px;
}

ol {
    margin-top: 0;
    margin-bottom: 25px;
    padding-left: 40px;
}

li {
    color: #60697b;
}

img {
    max-width: 100%;
    display: inline-block;
}

blockquote {
    border-left: 1px #000;
    margin-bottom: 25px;
    padding: 0;
    font-size: 17px;
    line-height: 1.7;
}

figure {
    margin-top: 50px;
    margin-bottom: 50px;
    margin-left: 0;
}

figcaption {
    color: #b8b9b9;
    margin-top: 15px;
    font-size: 16px;
}

.body {
    color: #60697b;
    font-family: Space Grotesk, sans-serif;
    font-size: 17px;
    font-weight: 400;
    line-height: 1.7;
}

.container {
    z-index: 2;
    width: 100%;
    height: 100%;
    max-width: 1290px;
    min-height: 30px;
    justify-content: center;
    align-items: center;
    margin-left: auto;
    margin-right: auto;
    padding-left: 40px;
    padding-right: 40px;
    transition: background-color .2s, color .2s;
    display: flex;
    position: relative;
    overflow: visible;
}

.sg-section {
    width: 100%;
    grid-column-gap: 16px;
    grid-row-gap: 16px;
    border-bottom: 1px solid #ebedf3;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr 1fr 1fr;
    grid-auto-columns: 1fr;
    padding-top: 150px;
    padding-bottom: 150px;
    display: grid;
}

.sg-block {
    margin-bottom: 40px;
    display: block;
}

.sg-button-block {
    margin-right: 60px;
    display: inline-block;
}

.sg-color-grid {
    width: 100%;
    grid-column-gap: 40px;
    grid-row-gap: 40px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr 1fr 1fr 1fr;
    grid-auto-columns: 1fr;
    display: grid;
}

.sg-color-block {
    height: 80px;
    margin-bottom: 10px;
    display: block;
}

.sg-margin-block {
    width: 100%;
    background-color: #f0f0f8;
    display: flex;
}

.utility-page-content {
    width: 300px;
    text-align: center;
    flex-direction: column;
    margin-left: auto;
    margin-right: auto;
    padding-top: 120px;
    padding-bottom: 120px;
    display: flex;
}

.utility-page-form {
    grid-row-gap: 30px;
    flex-direction: column;
    align-self: center;
    align-items: flex-start;
    margin-top: auto;
    margin-bottom: auto;
    display: flex;
}

.billing-card {
    background-color: #fff;
    border-radius: 8px;
    margin-left: 10px;
    margin-right: 10px;
    padding: 40px 20px 0;
}

.billing-min-height {
    min-height: 27.5rem;
}

/* Start billing pagination */
.pagination {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-top: 10px;
    padding-right: 10px;
}

.pagination-controls {
    display: flex;
    justify-content: flex-end;
    flex: 1;
}

.btn {
    margin: 0 10px;
    text-decoration: none;
    color: #605dba;
}

.disabled {
    color: grey;
    cursor: not-allowed;
}
/* End billing pagination */

.tps-btn {
    border-radius: 8px;
    padding: 12px 24px;
    line-height: 1.7;
    cursor: pointer;
    flex: 1;
    font-size: 17px;
    transition: all .2s ease-in-out;
    text-decoration: none;
    white-space: nowrap;
}

.tps-btn:hover {
    transform: translate(0, -3px);
    box-shadow: 0 5px 15px rgba(30, 34, 40, .15);
}

.tps-btn-main {
    color: white;
    background-color: #605dba;
    font-weight: 600;
}

.tps-btn-danger {
    color: white;
    background-color: #ff664c;
    font-weight: 600;
}

.jc-stretch {
    justify-content: stretch;
}

.jc-center {
    justify-content: center;
}

.jc-space-between {
    justify-content: space-between;
}

.ai-stretch {
    align-items: stretch;
}

.ai-center {
    align-items: center;
}

.d-flex-col {
    display: flex;
    flex-direction: column;
}

.d-flex-row {
    display: flex;
    flex-direction: row;
}

.d-flex-1 {
    flex: 1;
}

.gap-1rem {
    gap: 1rem;
}

.txt-center {
    text-align: center;
}

.no-wrap {
    white-space: nowrap;
}

.w-100 {
    width: 100%;
}

.w-50 {
    width: 50%;
}

.p-10 {
    padding: .3rem;
}

.card-padding {
    padding: 0px 20px 40px;
}

.color-success {
    color: #1fc228;
}

.color-danger {
    color: #ff664c;
}

.margin-none {
    margin: 0;
}

.margin-bottom-none {
    margin-bottom: 0;
}

.margin-bottom-5 {
    margin-bottom: 5px;
}

.margin-bottom-10 {
    margin-bottom: 10px;
}

.margin-bottom-15 {
    margin-bottom: 15px;
}

.margin-bottom-20 {
    margin-bottom: 20px;
}

.margin-bottom-25 {
    margin-bottom: 25px;
}

.margin-bottom-30 {
    margin-bottom: 30px;
}

.margin-bottom-35 {
    margin-bottom: 35px;
}

.margin-bottom-40 {
    margin-bottom: 40px;
}

.margin-bottom-45 {
    margin-bottom: 45px;
}

.margin-bottom-50 {
    margin-bottom: 50px;
}

.margin-bottom-55 {
    margin-bottom: 55px;
}

.margin-bottom-60 {
    margin-bottom: 60px;
}

.margin-bottom-65 {
    margin-bottom: 65px;
}

.margin-bottom-70 {
    margin-bottom: 70px;
}

.margin-bottom-75 {
    margin-bottom: 75px;
}

.margin-bottom-80 {
    margin-bottom: 80px;
}

.background-primary {
    background-color: #605dba;
}

.body-color {
    color: #60697b;
}

.text-primary {
    color: #605dba;
}

.text-secondary {
    color: #aab0bc;
}

.text-white, .link-white {
    color: #fff;
}

.text-emphasize {
    font-family: IBM Plex Serif, sans-serif;
    font-style: italic;
}

.text-gradient {
    -webkit-text-fill-color: transparent;
    background-image: linear-gradient(100deg, #605dba 20%, #3f78e0);
    -webkit-background-clip: text;
    background-clip: text;
}

.text-gradient.text-emphasize {
    padding-left: 2px;
    padding-right: 2px;
}

.display-1 {
    letter-spacing: -.01rem;
    flex: none;
    margin-bottom: 0;
    font-size: 56px;
    line-height: 1.15;
}

.display-1.margin-bottom-20 {
    margin-bottom: 20px;
}

.display-2 {
    letter-spacing: -.01rem;
    margin-bottom: 15px;
    font-size: 44px;
    line-height: 1.2;
}

.display-2.margin-bottom-none {
    margin-bottom: 0;
}

.display-2.margin-bottom-25 {
    margin-bottom: 25px;
}

.display-2.margin-bottom-30 {
    margin-bottom: 30px;
}

.display-3 {
    letter-spacing: -.01rem;
    margin-bottom: 15px;
    font-size: 36px;
    line-height: 1.25;
}

.paragraph.margin-bottom-30 {
    margin-bottom: 0;
    padding-top: 10px;
}

.paragraph-large {
    margin-bottom: 35px;
    font-size: 25px;
    line-height: 1.5;
}

.label {
    letter-spacing: .02rem;
    text-transform: uppercase;
    font-size: 16px;
    font-weight: 600;
    line-height: 1.35;
}

.unicon {
    font-family: Unicons, sans-serif;
    line-height: 1;
}

.material-icon {
    font-family: Material Icons, sans-serif;
    line-height: 1;
}

.button {
    float: none;
    color: #fff;
    text-align: center;
    object-fit: fill;
    background-color: #605dba;
    border-radius: 8px;
    flex: none;
    align-self: flex-start;
    padding: 12px 24px;
    font-size: 17px;
    font-weight: 600;
    line-height: 1.7;
    transition: all .2s ease-in-out;
    position: static;
}

.button:hover {
    color: #fff;
    border-color: #605dba;
    transform: translate(0, -3px);
    box-shadow: 0 5px 15px rgba(30, 34, 40, .15);
}

.disabled-button {
    background-color: #ccc; /* Faded gray color */
    cursor: not-allowed; /* Indicate that the button is not clickable */
    border: none; /* Optional: Remove border if you have any */
    color: #888; /* Faded text color */
    pointer-events: none; /* Makes sure the button doesn't react to clicks */
}


.button.cc-small {
    padding: 10px 22px;
}

.button.cc-small.cc-form {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
}

.button.cc-small.cc-form:hover {
    transform: none;
}

.button.cc-large {
    padding: 16px 28px 15px;
    font-size: 18px;
}

.image-link {
    width: 100%;
    cursor: none;
    transition: color .2s;
}

.link-hover {
    border-bottom: 1px solid rgba(0, 0, 0, 0);
    transition: border-color .2s, color .2s;
}

.link-hover:hover {
    color: #605dba;
    border-bottom-color: #605dba;
}

.link-hover.link-white:hover {
    color: #fff;
    border-bottom-color: #fff;
}

.shadow {
    box-shadow: 0 5px 35px rgba(30, 34, 40, .07);
}

.card {
    background-color: #fff;
    border-radius: 8px;
    padding: 40px;
}

.card.shadow {
    flex-direction: column;
    flex: 1;
    justify-content: space-between;
    padding-left: 40px;
    display: flex;
    box-shadow: 0 5px 35px rgba(30, 34, 40, .07);
}

.background-primary-pale {
    background-color: #e6e5f4;
}

.background-primary-soft {
    background-color: #f0f0f8;
}

.background-light {
    background-color: #fcfcfd;
}

.background-dark {
    background-color: #343f52;
}

.navbar-wrapper {
    justify-content: space-between;
    align-items: flex-end;
    display: flex;
}

.navbar {
    z-index: 1999;
    width: 100%;
    -webkit-backdrop-filter: blur(5px);
    backdrop-filter: blur(5px);
    background-color: rgba(255, 255, 255, 0);
    position: -webkit-sticky;
    position: sticky;
    top: 0;
}

.navbar-space {
    height: 10px;
}

.navbar-inner {
    z-index: 5;
    width: 100%;
    background-color: rgba(0, 0, 0, 0);
    margin-left: auto;
    margin-right: auto;
}

.nav-menu-wrapper {
    width: 100%;
}

.nav-menu-flex {
    align-items: center;
    display: flex;
}

.nav-menu {
    width: 100%;
    grid-column-gap: 40px;
    grid-row-gap: 20px;
    justify-content: center;
    align-items: center;
    margin-bottom: 0;
    padding-bottom: 0;
    padding-left: 20px;
    padding-right: 20px;
    display: flex;
}

.nav-link {
    color: #343f52;
    align-items: center;
    margin-left: 0;
    margin-right: 0;
    padding: 25px 0;
    font-weight: 600;
    transition: color .2s;
    display: flex;
}

.nav-link.w--current {
    color: #605dba;
}

.burger-line {
    width: 25px;
    height: 3px;
    background-color: #343f52;
    margin-top: 5px;
    margin-bottom: 5px;
}

.nav-menu-flex-mobile {
    display: flex;
}

.navbar-wrapper-mobile {
    justify-content: space-between;
    align-items: center;
    display: none;
}

.navbar-inner-mobile {
    background-color: rgba(0, 0, 0, 0);
    flex-direction: column;
    align-items: center;
    display: none;
    position: relative;
    top: 0%;
    bottom: auto;
    left: 0%;
    right: 0%;
}

.navbar-brand-mobile {
    display: none;
}

.nav-link-mobile {
    height: 143px;
    color: #303030;
    align-items: center;
    margin-left: 0;
    margin-right: 0;
    padding: 0;
    font-size: 14px;
    font-weight: 500;
    transition: color .2s;
    display: flex;
}

.nav-link-mobile:hover {
    color: #605dba;
}

.nav-link-mobile:focus-visible {
    outline-offset: 0px;
    color: #0050bd;
    border-radius: 4px;
    outline: 2px solid #0050bd;
}

.nav-link-mobile[data-wf-focus-visible] {
    outline-offset: 0px;
    color: #0050bd;
    border-radius: 4px;
    outline: 2px solid #0050bd;
}

.navbar-button-wrapper {
    flex: none;
}

.hero-grid {
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    padding-top: 100px;
    padding-bottom: 170px;
    display: grid;
}

.hero {
    min-height: 60vh;
    align-items: center;
    display: flex;
    position: relative;
}

.hero-image-wrapper {
    width: 50%;
    height: 100%;
    object-fit: cover;
    position: absolute;
    top: 0;
    right: 0;
}

.hero-content {
    height: 100%;
    padding-right: 100px;
    position: relative;
}

.play {
    z-index: 3;
    justify-content: center;
    position: absolute;
    top: 50%;
    left: 0;
    transform: translate(-50%, -50%);
}

.play-button {
    width: 75px;
    height: 75px;
    color: #fff;
    background-color: #605dba;
    border-radius: 50%;
    justify-content: center;
    align-items: center;
    font-size: 35px;
    display: flex;
}

.play-button:hover {
    color: #fff;
}

.doodle-arrow {
    z-index: auto;
    position: absolute;
    top: auto;
    bottom: 3%;
    left: auto;
    right: 0%;
}

.doodle-shine {
    position: absolute;
    top: -7%;
    left: -6%;
}

.reasons {
    padding-top: 140px;
    padding-bottom: 140px;
}

.tabs-menu {
    grid-column-gap: 30px;
    grid-row-gap: 20px;
    justify-content: space-between;
    display: flex;
}

.tab {
    background-color: rgba(0, 0, 0, 0);
}

.tab.card {
    grid-column-gap: 20px;
    flex-direction: row;
    flex: 1;
    padding: 30px;
    transition: box-shadow .2s, background-color .2s, color .2s;
    display: flex;
}

.tab.card:hover {
    color: #343f52;
    background-color: #fff;
    box-shadow: 0 5px 35px rgba(30, 34, 40, .07);
}

.tab.card.w--current {
    background-color: rgba(0, 0, 0, 0);
    box-shadow: 0 5px 35px rgba(30, 34, 40, .07);
}

.tab-pane-grid {
    grid-column-gap: 70px;
    grid-row-gap: 50px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    display: grid;
}

.tabs-content {
    margin-top: 60px;
}

.step {
    font-size: 50px;
    font-weight: 600;
    line-height: 1;
}

.bullet-list {
    grid-column-gap: 5px;
    grid-row-gap: 5px;
    flex-direction: column;
    display: flex;
}

.bullet-list-item {
    grid-column-gap: 10px;
    display: flex;
}

.bullet {
    width: 20px;
    height: 20px;
    color: #605dba;
    background-color: #e6e5f4;
    border-radius: 50%;
    flex: none;
    justify-content: center;
    align-items: center;
    margin-top: 4px;
    font-size: 15px;
    line-height: 1;
    display: flex;
}

.rounded {
    width: 100%;
    border-radius: 8px;
}

.headline-reasons {
    max-width: 660px;
    grid-column-gap: 16px;
    grid-row-gap: 16px;
    text-align: center;
    grid-template-rows: auto auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    margin-bottom: 20px;
    margin-left: auto;
    margin-right: auto;
    padding-top: 60px;
}

.headline-customers {
    max-width: 750px;
    grid-column-gap: 16px;
    grid-row-gap: 16px;
    text-align: center;
    grid-template-rows: auto auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    margin-bottom: 50px;
    margin-left: auto;
    margin-right: auto;
}

.testimonials {
    grid-column-gap: 30px;
    grid-row-gap: 30px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr 1fr;
    grid-auto-columns: 1fr;
    align-items: start;
    display: grid;
}

.testimonial {
    display: flex;
}

.testimonial-card-footer {
    grid-column-gap: 20px;
    grid-row-gap: 20px;
    align-items: center;
    display: flex;
}

.block-quote-with-icon {
    position: relative;
}

.quote-icon {
    position: absolute;
    top: 0%;
    bottom: auto;
    left: -10px;
    right: auto;
}

.avatar {
    width: 70px;
    height: 70px;
    border-radius: 50%;
}

.rating {
    color: #fcc032;
    letter-spacing: -3px;
    margin-bottom: 20px;
    margin-left: -3px;
    font-size: 25px;
    line-height: 1;
    display: flex;
}

.customers {
    width: 100%;
    flex-direction: column;
    padding-top: 140px;
    padding-bottom: 140px;
    display: inline-block;
}

.services-grid {
    width: 100%;
    grid-column-gap: 0px;
    grid-row-gap: 80px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr 1fr 1fr 1fr 1fr 1fr 1fr 1fr 1fr 1fr 1fr;
    grid-auto-columns: 1fr;
    padding-top: 60px;
    padding-bottom: 60px;
    display: grid;
    position: relative;
}

.sticky {
    position: -webkit-sticky;
    position: sticky;
    top: 140px;
}

.service.margin-bottom-30 {
    flex: 1;
}

.card-inner {
    grid-column-gap: 30px;
    flex: 1;
    justify-content: center;
    align-self: stretch;
    display: flex;
}

.service-icon {
    width: 80px;
    flex: none;
}

.facts {
    min-height: auto;
    grid-column-gap: 16px;
    grid-row-gap: 16px;
    grid-template-rows: auto;
    grid-template-columns: 1fr;
    grid-auto-columns: 1fr;
    align-content: start;
    justify-content: stretch;
    align-items: center;
    margin-bottom: 0;
    padding-top: 40px;
    padding-bottom: 60px;
    display: grid;
    position: relative;
}

.facts-image {
    width: 30%;
    height: 50%;
    max-width: 10%;
    object-fit: cover;
    flex: 1;
    align-self: center;
    position: relative;
    top: 0%;
    bottom: auto;
    left: auto;
    right: 0%;
    overflow: scroll;
}

.facts-grid {
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    padding-top: 0;
    padding-bottom: 160px;
    display: grid;
}

.facts-content {
    height: 100%;
    padding-left: 100px;
    position: relative;
}

.numbers-grid {
    grid-column-gap: 16px;
    grid-row-gap: 16px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    display: grid;
}

.numbers-grid.cc-margin-top {
    margin-top: 20px;
}

.image-grid {
    width: 100%;
    grid-column-gap: 25px;
    grid-row-gap: 25px;
    grid-template-rows: auto auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    display: grid;
}

.solutions-grid {
    width: 100%;
    grid-column-gap: 70px;
    grid-row-gap: 0px;
    grid-template-rows: auto;
    grid-template-columns: 1fr;
    grid-auto-columns: 1fr;
    align-self: auto;
    align-items: center;
    padding-top: 0;
    padding-bottom: 0;
    display: grid;
}

.image-padding {
    width: 100%;
    padding-left: 25px;
    padding-right: 25px;
}

.features-grid {
    grid-column-gap: 30px;
    grid-row-gap: 30px;
    grid-template-rows: auto;
    grid-template-columns: 1fr;
    grid-auto-columns: 1fr;
    display: grid;
}

.pricing {
    width: 100%;
    flex-direction: column;
    padding-top: 140px;
    padding-bottom: 140px;
    display: inline-block;
}

.headline-pricing {
    max-width: 850px;
    grid-column-gap: 16px;
    grid-row-gap: 16px;
    text-align: center;
    grid-template-rows: auto auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    margin-bottom: 50px;
    margin-left: auto;
    margin-right: auto;
}

.howto-grid {
    width: 100%;
    grid-column-gap: 20px;
    grid-row-gap: 20px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr 1fr 1fr;
    grid-auto-columns: 1fr;
    align-content: start;
    align-items: center;
    margin-bottom: 0;
    display: grid;
}

.bold-text {
    font-weight: 600;
    text-decoration: none;
}

.price-currency {
    padding-top: 8px;
    padding-right: 5px;
    font-size: 20px;
    font-weight: 400;
}

.howto-card-inner {
    flex-direction: column;
    margin-left: auto;
    margin-right: auto;
}

.profile-card-inner {
    flex-direction: column;
    /* margin-left: auto; */
    /* margin-right: auto; */
}

.signup-card-inner {
    flex-direction: column;
    margin-left: auto;
    margin-right: auto;
    width: 80%;
}

.signup-card.card.shadow {
    margin-left: 10px;
    margin-right: 10px;
    padding: 40px 20px;
    width: 80%;
    max-width: 30em;
}

.price-duration {
    align-self: flex-end;
    padding-bottom: 10px;
    font-size: 16px;
    font-weight: 400;
}

.howto-card {
    padding-bottom: 50px;
    display: flex;
}

.howto-card.card.shadow {
    margin-left: 10px;
    margin-right: 10px;
    padding-top: 40px;
    padding-bottom: 40px;
}

.howto-card.card.shadow.cc-larger {
    padding-top: 70px;
    padding-bottom: 80px;
}

.faq-wrapper {
    grid-column-gap: 50px;
    grid-row-gap: 30px;
    flex-direction: column;
    grid-template-rows: auto auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    display: grid;
}

.faq-item {
    margin-bottom: 30px;
    display: inline-block;
}

.faq-icon {
    width: 42px;
    height: 42px;
    color: #fff;
    background-color: #605dba;
    border-radius: 50%;
    justify-content: center;
    align-items: center;
    font-size: 30px;
    display: flex;
}

.faq {
    flex: 1;
}

.faq-item-inner {
    grid-column-gap: 30px;
    display: flex;
}

.footer {
    padding-top: 100px;
    padding-bottom: 70px;
}

.footer.background-dark {
    color: #fff;
}

.footer-grid {
    width: 100%;
    grid-column-gap: 50px;
    grid-row-gap: 50px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr 1fr;
    grid-auto-columns: 1fr;
    display: grid;
}

.address {
    max-width: 90%;
}

.unordered-list {
    padding-left: 0;
    list-style-type: none;
}

.hero-image {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.price {
    font-size: 48px;
    font-weight: 500;
    line-height: 1;
}

.divider {
    width: 100%;
    height: 1px;
    background-color: rgba(164, 174, 198, .2);
    margin-top: 50px;
    margin-bottom: 70px;
}

.input-group {
    display: flex;
}

.text-field {
    height: 48px;
    color: #fff;
    border: 1px solid rgba(52, 63, 82, .2);
    border-radius: 8px;
    padding-top: 10px;
    padding-bottom: 10px;
}

.text-field:focus {
    border-width: 1px;
    border-color: #605dba;
}

.text-field::-ms-input-placeholder {
    color: #aab0bc;
}

.text-field::placeholder {
    color: #aab0bc;
}

.text-field-dark {
    height: 48.8px;
    color: #fff;
    background-color: rgba(255, 255, 255, .03);
    border: 1px solid rgba(255, 255, 255, .1);
    border-right-width: 0;
    border-top-left-radius: 8px;
    border-bottom-left-radius: 8px;
}

.text-field-dark:focus {
    border-width: 1px;
    border-color: #605dba;
}

.text-field-dark::-ms-input-placeholder {
    color: #aab0bc;
}

.text-field-dark::placeholder {
    color: #aab0bc;
}

.field-label {
    display: none;
}

.footer-cta {
    justify-content: space-between;
    align-items: center;
    display: flex;
}

.join {
    max-width: 600px;
}

.play-button-pulse {
    z-index: -1;
    width: 70px;
    height: 70px;
    background-color: rgba(96, 93, 186, .5);
    border-radius: 100%;
    position: absolute;
    top: 50%;
    bottom: 0%;
    left: 50%;
    right: 0%;
    transform: translate(0, -50%) translate(-50%);
}

.navbar-shadow {
    height: 100%;
    position: absolute;
    top: auto;
    bottom: 0%;
    left: 0%;
    right: 0%;
    box-shadow: 0 0 25px rgba(30, 34, 40, .06);
}

.social-links {
    grid-column-gap: 20px;
    margin-bottom: 0;
    padding-left: 0;
    display: flex;
}

.social-link-item {
    line-height: 1;
}

.social-link {
    color: #fff;
    font-size: 20px;
    transition: transform .2s;
    display: flex;
}

.social-link:hover {
    color: #fff;
    transform: translate(0, -3px);
}

.page-headline {
    width: 80%;
    padding-top: 100px;
}

.page-title {
    letter-spacing: -.03em;
    flex: none;
    font-size: 200px;
    font-weight: 400;
    line-height: 208px;
}

.inner-wrapper {
    height: 100%;
    flex-direction: column;
    justify-content: space-between;
    padding-top: 100px;
    padding-bottom: 100px;
    display: flex;
}

.wrapper-narrow {
    width: 65%;
}

.wrapper-narrow.cc-center {
    text-align: center;
    flex-direction: column;
    align-items: center;
    margin-left: auto;
    margin-right: auto;
    display: flex;
}

.brand {
    flex: none;
}

.div-block {
    flex: 1;
}

.submit-button {
    display: none;
    overflow: visible;
}

.div-block-2 {
    text-align: center;
    padding: 0 60px 60px;
}

.paragraph-medium {
    margin-bottom: 0;
    font-size: 21px;
    line-height: 1.5;
}

.text-block {
    flex: 0 auto;
}

.doodle-shine-copy {
    position: absolute;
    top: 220px;
    left: auto;
    right: 40px;
}

.login {
    width: 60%;
    flex-direction: column;
    padding-top: 60px;
    padding-bottom: 60px;
    display: inline-block;
}

.signup {
    width: 100%;
    flex-direction: column;
    padding-top: 60px;
    padding-bottom: 60px;
    display: inline-block;
}

.signup-grid {
    /* width: 50%; */
    justify-items: center;
    grid-column-gap: 20px;
    grid-row-gap: 20px;
    grid-template-rows: auto;
    grid-template-columns: 1fr;
    grid-auto-columns: 1fr;
    align-content: start;
    align-items: center;
    margin-bottom: 0;
    margin-left: auto;
    margin-right: auto;
    display: grid;
}

.profile-grid {
    width: 100%;
    grid-column-gap: 20px;
    grid-row-gap: 20px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 3fr;
    grid-auto-columns: 1fr;
    align-content: start;
    align-items: start;
    margin-bottom: 0;
    display: grid;
}

.prices-grid {
    width: 100%;
    grid-column-gap: 20px;
    grid-row-gap: 20px;
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr 1fr;
    grid-auto-columns: 1fr;
    align-content: start;
    align-items: center;
    margin-bottom: 0;
    display: grid;
}

.pricing-card {
    padding-bottom: 50px;
    display: flex;
}


.pricing-card.card.shadow {
    margin-left: 10px;
    margin-right: 10px;
    padding: 40px 20px;
}

.pricing-card.card.shadow.cc-larger {
    padding-top: 70px;
    padding-bottom: 80px;
}

.code-snippets {
    border: 1px solid #e1e4e8; /* Add a subtle border */
    padding: 10px;
    border-radius: 5px;
    font-family: 'Courier New', Courier, monospace; /* Use a monospace font */
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1); /* Optional shadow for aesthetics */
}

.snippet-tabs {
    list-style-type: none;
    padding: 0;
    margin-bottom: 0;
}

.snippet-tabs li {
    display: inline;
}

.tablink {
    padding: 10px 15px;
    cursor: pointer;
    background-color: #fff;
    /* border: none; */
    /* outline: none; */
    border: 1px solid rgba(52, 63, 82, .2);
    border-radius: 8px;
    color: #605dba;
    transition: background-color 0.3s;
}

.tablink:hover {
    color: #605dba;
    /* background-color: #ddd; */
}

.tablink.active {
    color: #fff;
    background-color: #605dba;
}

.snippet-content {
    /* border: 1px solid #ccc; */
    /* padding: 10px; */
    overflow-y: auto;
}

.api {
    min-height: auto;
    justify-content: center;
    align-items: center;
    margin-bottom: 0;
    padding-top: 40px;
    padding-bottom: 60px;
    display: flex;
    position: relative;
}

.api-grid {
    grid-template-rows: auto;
    grid-template-columns: 1fr 1fr;
    grid-auto-columns: 1fr;
    padding-top: 0;
    padding-bottom: 0;
    display: grid;
}

.api-content {
    height: 100%;
    padding-left: 10px;
    position: relative;
}

.image {
    padding-left: 10px;
    padding-right: 10px;
}

.bullet-no {
    width: 20px;
    height: 20px;
    color: #605dba;
    -webkit-text-stroke-color: #605dba;
    background-color: #e6e5f4;
    border-radius: 50%;
    flex: none;
    justify-content: center;
    align-items: center;
    margin-top: 4px;
    font-size: 15px;
    line-height: 1;
    display: flex;
}

.bullet-list-item-no {
    grid-column-gap: 10px;
    color: rgba(96, 105, 123, .5);
    font-style: normal;
    text-decoration: none;
    display: flex;
}

.text-block-2 {
    color: rgba(96, 105, 123, .3);
    text-decoration: none;
}

.text-block-3, .text-block-4 {
    color: rgba(96, 105, 123, .3);
}

.heading {
    text-align: center;
    flex-direction: row;
    justify-content: center;
    align-items: center;
    margin-bottom: 0;
    display: block;
}

.container-2 {
    justify-content: center;
    align-items: center;
    display: flex;
}

.container-3 {
    flex-direction: row;
    justify-content: center;
    align-items: flex-start;
    margin-bottom: 0;
    padding-bottom: 60px;
    display: none;
    overflow: scroll;
}

.container-copy {
    z-index: 2;
    width: 100%;
    height: 100%;
    max-width: 1290px;
    min-height: 30px;
    justify-content: center;
    align-items: center;
    margin-left: auto;
    margin-right: auto;
    padding-left: 10px;
    padding-right: 10px;
    transition: background-color .2s, color .2s;
    display: flex;
    position: relative;
    overflow: visible;
}

.test.margin-bottom-30 {
    flex: 1;
}

@media screen and (min-width: 1280px) {
    .section.background-primary-soft {
        grid-column-gap: 16px;
        grid-row-gap: 16px;
        grid-template-rows: auto auto;
        grid-template-columns: 1fr 1fr;
        grid-auto-columns: 1fr;
        display: block;
    }

    .container {
        max-width: 1350px;
    }

    .sg-section {
        grid-column-gap: 16px;
        grid-row-gap: 16px;
        grid-template-rows: auto;
        grid-template-columns: 1fr 1fr 1fr;
        grid-auto-columns: 1fr;
    }

    .utility-page-content {
        text-align: center;
        margin-top: auto;
        margin-bottom: auto;
    }

    .nav-menu {
        padding-left: 60px;
        padding-right: 60px;
    }

    .hero-grid {
        flex: 0 auto;
        justify-content: stretch;
        align-self: auto;
        align-items: stretch;
        justify-items: stretch;
        margin-left: auto;
        margin-right: auto;
    }

    .hero-content {
        margin-left: auto;
        margin-right: auto;
        padding-right: 60px;
    }

    .headline-reasons {
        margin-bottom: 20px;
    }

    .facts {
        z-index: auto;
        width: 100%;
        height: 100%;
        max-width: 1350px;
        grid-column-gap: 0px;
        grid-row-gap: 0px;
        grid-template-rows: auto;
        grid-template-columns: 1fr;
        grid-auto-columns: 1fr;
        align-content: center;
        justify-content: center;
        justify-items: center;
        margin-left: auto;
        margin-right: auto;
        display: flex;
    }

    .solutions-grid {
        align-items: center;
        padding: 20px;
    }

    .features-grid {
        grid-column-gap: 30px;
        grid-row-gap: 30px;
    }

    .howto-grid {
        justify-content: center;
        justify-items: center;
    }

    .faq-wrapper {
        display: none;
    }

    .page-headline {
        width: 75%;
    }

    .wrapper-narrow {
        width: 55%;
    }

    .wrapper-narrow.cc-center {
        width: 63%;
    }

    .brand {
        order: 0;
        align-self: auto;
    }

    .div-block-2 {
        padding-bottom: 60px;
    }

    .div-block-3 {
        text-align: center;
    }

    .text-field-2 {
        max-width: 300px;
        object-fit: fill;
        margin-left: 60px;
        margin-right: 60px;
        display: block;
        overflow: visible;
    }

    .container-copy {
        max-width: 1350px;
    }

    .test.margin-bottom-30 {
        max-width: 500px;
        margin-bottom: 50px;
        margin-left: 0;
        margin-right: auto;
    }

    .field-label-3 {
        font-size: 25px;
    }

    .recaptcha {
        float: none;
    }

    .div-block-4 {
        float: none;
        text-align: center;
        object-fit: fill;
        justify-content: center;
        align-items: center;
        display: flex;
        position: relative;
        height: 100%;
    }
}

@media screen and (max-width: 991px) {
    .sg-block {
        margin-bottom: 40px;
    }

    .display-1 {
        font-size: 45px;
        line-height: 52px;
    }

    .display-2 {
        font-size: 37px;
        line-height: 44px;
    }

    .display-3 {
        font-size: 34px;
        line-height: 44px;
    }

    .paragraph-large {
        margin-bottom: 30px;
    }

    .button {
        position: relative;
    }

    .logo {
        flex: none;
    }

    .navbar-space {
        display: none;
    }

    .navbar-inner {
        display: none;
        position: relative;
    }

    .nav-menu-wrapper {
        z-index: 999;
        width: 100%;
        height: auto;
        background-color: #fff;
        position: absolute;
    }

    .nav-menu-flex {
        flex-direction: column;
        padding-left: 30px;
        padding-right: 30px;
    }

    .nav-menu {
        grid-row-gap: 0px;
        flex-flow: column wrap;
        justify-content: space-around;
        align-items: flex-start;
        padding-left: 0;
        display: flex;
    }

    .nav-link {
        height: auto;
        padding: 6px 0;
    }

    .menu-button {
        margin-left: 10px;
        padding: 0;
    }

    .menu-button.w--open {
        color: #60697b;
        background-color: rgba(0, 0, 0, 0);
    }

    .nav-menu-flex-mobile {
        flex-direction: column;
        padding: 30px 40px;
    }

    .nav-menu-wrapper-mobile {
        background-color: #343f52;
        margin-left: 50px;
        margin-right: 50px;
        transform: translate(0, 10px);
    }

    .navbar-wrapper-mobile {
        display: flex;
    }

    .navbar-inner-mobile {
        align-items: center;
        display: flex;
    }

    .navbar-brand-mobile {
        padding-top: 24px;
        padding-bottom: 24px;
        display: flex;
    }

    .nav-link-mobile {
        height: auto;
        color: #fff;
        padding: 6px 0;
        font-size: 16px;
    }

    .nav-link-mobile.w--current {
        color: #605dba;
    }

    .hero-grid {
        padding-top: 60px;
        padding-bottom: 20px;
        display: flex;
    }

    .hero {
        display: block;
    }

    .hero-image-wrapper {
        width: 100%;
        position: relative;
    }

    .hero-content {
        padding-right: 0;
    }

    .play {
        left: 50%;
    }

    .doodle-arrow {
        display: none;
    }

    .doodle-shine {
        top: -10%;
    }

    .reasons {
        padding-top: 120px;
        padding-bottom: 120px;
    }

    .tabs-menu {
        flex-direction: column;
    }

    .tab-pane-grid {
        flex-direction: column;
        display: flex;
    }

    .headline-customers {
        margin-top: 0;
    }

    .testimonials {
        column-count: 2;
        grid-template-columns: 1fr 1fr;
    }

    .customers {
        padding-top: 120px;
        padding-bottom: 110px;
    }

    .services-grid {
        flex-direction: column;
        padding-top: 60px;
        padding-bottom: 120px;
        display: flex;
    }

    .sticky {
        position: relative;
        top: auto;
    }

    .facts {
        display: block;
    }

    .facts-image {
        width: 100%;
        position: relative;
    }

    .facts-grid {
        padding-top: 120px;
        padding-bottom: 120px;
        display: flex;
    }

    .facts-content {
        padding-left: 0;
    }

    .solutions-grid {
        grid-template-columns: 1fr;
        padding-top: 20px;
        padding-bottom: 20px;
    }

    .image-padding {
        width: 100%;
    }

    .features-grid {
        grid-column-gap: 50px;
    }

    .pricing {
        padding-top: 120px;
        padding-bottom: 120px;
    }

    .headline-pricing {
        margin-top: 0;
    }

    .howto-grid {
        grid-template-columns: 1fr 1fr;
        grid-auto-columns: 1fr;
        align-content: center;
        justify-content: center;
    }

    .howto-card.card.shadow.cc-larger {
        padding-top: 50px;
        padding-bottom: 60px;
    }

    .faq-wrapper {
        column-count: auto;
    }

    .footer.background-dark {
        padding-top: 80px;
        padding-bottom: 80px;
    }

    .footer-grid {
        width: 100%;
        grid-template-rows: auto auto;
        grid-template-columns: 1fr 1fr 1fr;
    }

    .footer-cta {
        grid-row-gap: 10px;
        flex-direction: column;
        align-items: flex-start;
    }

    .join {
        max-width: none;
    }

    .page-title {
        font-size: 140px;
        line-height: 148px;
    }

    .wrapper-narrow {
        width: 100%;
    }

    .div-block-2 {
        padding-bottom: 20px;
    }

    .paragraph-medium {
        margin-bottom: 30px;
    }

    .doodle-shine-copy {
        top: -10%;
    }

    .pricing-copy {
        padding-top: 120px;
        padding-bottom: 120px;
    }

    .prices-grid {
        grid-template-columns: 1fr 1fr;
        grid-auto-columns: 1fr;
        align-content: center;
        justify-content: center;
    }

    .pricing-card.card.shadow.cc-larger {
        padding-top: 50px;
        padding-bottom: 60px;
    }

    .api {
        padding-bottom: 0;
        display: block;
    }

    .api-grid {
        flex-direction: column;
        padding-top: 0;
        padding-bottom: 120px;
        display: flex;
    }

    .api-content {
        padding-left: 0;
    }

    .image {
        padding-left: 0;
        padding-right: 0;
    }
}

@media screen and (max-width: 767px) {

    .profile-grid {
        grid-template-columns: 1fr;
        grid-auto-columns: 1fr;
    }

    .snippet-content {
        max-width: 300px;
        font-size: small;

    }

    .snippet-tabs li {
        display: block; /* Stack tabs vertically */
    }

    .tablink {
        display: block;
        width: 100%;
        text-align: left;
        margin-bottom: 5px;
    }

    .sg-section {
        grid-row-gap: 60px;
        grid-template-columns: 1fr;
        padding-top: 120px;
        padding-bottom: 120px;
    }

    .sg-color-grid {
        grid-template-columns: 1fr 1fr 1fr 1fr;
    }

    .sg-color-block {
        width: 25%;
    }

    .paragraph-large {
        font-size: 22px;
        line-height: 34px;
    }

    .nav-menu {
        flex-direction: column;
        padding-left: 0;
    }

    .nav-link {
        padding-top: 10px;
        padding-bottom: 10px;
        display: inline-block;
    }

    .navbar-brand-mobile {
        padding-left: 0;
    }

    .doodle-shine {
        top: -9%;
        left: -8%;
    }

    .testimonials {
        column-count: 1;
        flex-direction: column;
        display: flex;
    }

    .services-grid {
        padding-top: 60px;
        padding-bottom: 40px;
    }

    .numbers-grid.cc-margin-top {
        grid-template-rows: auto auto;
    }

    .features-grid {
        flex-direction: column;
        display: flex;
    }

    .howto-grid {
        grid-template-rows: auto auto;
    }

    .footer-grid {
        flex-direction: column;
        display: flex;
    }

    .page-title {
        font-size: 50px;
        line-height: 58px;
    }

    .paragraph-medium {
        font-size: 22px;
        line-height: 34px;
    }

    .doodle-shine-copy {
        top: -9%;
        left: -8%;
    }

    .pricing-copy {
        padding-top: 60px;
    }

    .prices-grid {
        grid-template-rows: auto auto;
    }

    .api-grid {
        flex-direction: column;
        padding-top: 0;
    }

    .image {
        padding-left: 0;
        padding-right: 0;
    }
}

@media screen and (max-width: 479px) {
    .section.background-light {
        display: none;
    }

    .container {
        padding-left: 20px;
        padding-right: 20px;
    }

    .sg-button-block {
        margin-bottom: 20px;
    }

    .sg-color-grid {
        grid-template-columns: 1fr 1fr;
    }

    .display-1.margin-bottom-20 {
        text-align: center;
    }

    .paragraph-large {
        text-align: center;
        font-size: 18px;
    }

    .button {
        width: auto;
        font-size: 16px;
    }

    .card.shadow {
        padding: 20px 0;
    }

    .nav-menu-wrapper {
        width: 80%;
    }

    .nav-menu {
        flex-direction: column;
    }

    .nav-menu-wrapper-mobile {
        width: auto;
        margin-left: 20px;
        margin-right: 20px;
    }

    .hero-grid {
        padding-top: 20px;
        padding-bottom: 0;
    }

    .doodle-shine {
        display: none;
    }

    .tab.card {
        grid-row-gap: 20px;
        flex-direction: column;
    }

    .headline-reasons {
        margin-bottom: 10px;
        padding-top: 40px;
    }

    .card-inner {
        grid-row-gap: 30px;
        flex-direction: column;
    }

    .image-grid {
        flex-direction: column;
        display: flex;
    }

    .solutions-grid {
        padding-top: 0;
        padding-bottom: 0;
    }

    .image-padding {
        padding-left: 0;
        padding-right: 0;
    }

    .howto-card-inner {
        padding-left: 10px;
        padding-right: 10px;
    }

    .faq-wrapper {
        display: none;
    }

    .text-field, .text-field-dark {
        height: 47px;
    }

    .div-block-2 {
        padding-bottom: 0;
        padding-left: 0;
        padding-right: 0;
    }

    .paragraph-medium {
        font-size: 15px;
    }

    .paragraph-medium.margin-bottom-30 {
        font-size: 17px;
    }

    .field-label-2 {
        font-size: 15px;
    }

    .text-field-2 {
        /* max-width: 70%; */
        margin-left: auto;
        margin-right: auto;
        padding-left: 0;
        padding-right: 0;
    }

    .doodle-shine-copy {
        display: none;
    }

    .pricing-copy {
        padding-top: 40px;
        padding-bottom: 40px;
    }

    .api-grid {
        flex-direction: column;
        padding-top: 0;
        padding-bottom: 0;
    }

    .image {
        padding-left: 0;
        padding-right: 0;
    }

    .container-copy {
        padding-left: 20px;
        padding-right: 20px;
    }

    .field-label-3, .form {
        text-align: center;
    }

    .div-block-5 {
        flex: 0 auto;
        overflow: scroll;
    }
}

#w-node-dc678c3f-8d8f-00ba-7466-144a35cd5f25-13e4c860 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-d0740bb6-cbf7-e994-b356-8f3c7d83dc8d-13e4c860 {
    grid-area: span 1 / span 1 / span 1 / span 1;
    align-self: center;
    justify-self: center;
}

#w-node-_46491234-f3d0-02a7-628d-9a38c3c37b6e-13e4c860 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-_46491234-f3d0-02a7-628d-9a38c3c37b7a-13e4c860 {
    justify-self: auto;
}

#w-node-_1d70a054-74c4-ff0a-a36b-00992d0f7cc6-13e4c860, #w-node-_9b908ccf-3f37-e264-b886-6d1f5dcd9ee9-13e4c860, #w-node-_14e8aef8-5200-041d-0346-c5a601590e52-13e4c860, #w-node-f2b417d0-d666-cff4-e74c-46a26350dc24-13e4c860 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-_890ab92c-649c-c487-5e27-0c25c2f4a261-13e4c860 {
    grid-area: span 1 / span 1 / span 1 / span 1;
    align-self: center;
    justify-self: center;
}

#w-node-_890ab92c-649c-c487-5e27-0c25c2f4a267-13e4c860 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-_890ab92c-649c-c487-5e27-0c25c2f4a269-13e4c860 {
    justify-self: auto;
}

#w-node-fc447acc-e5d7-6a45-4032-aca7ca736ffd-13e4c860 {
    grid-area: 1 / 2 / 2 / 3;
}

#w-node-d7a33e1f-cb8d-43b7-8d9f-8f277cf0b84d-13e4c860 {
    grid-area: 1 / 1 / 2 / 2;
    align-self: center;
}

#w-node-_72b8af2d-5524-9ad8-95e6-936ff7033a26-13e4c860 {
    grid-area: span 1 / span 5 / span 1 / span 5;
    align-self: start;
}

#w-node-e936af14-d0d6-3191-8d17-d905eda72cd8-13e4c860 {
    grid-area: 1 / 7 / 2 / 13;
}

#w-node-_11e2dc3d-d1e1-458c-44c2-5749cd8efbcf-cd8efba7, #w-node-_11e2dc3d-d1e1-458c-44c2-5749cd8efbe5-cd8efba7 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-_2dbc92e1-f640-1dc3-f27e-e52bbea09c40-13e4c862 {
    grid-area: 1 / 3 / 2 / 11;
    justify-self: center;
}

#w-node-b970029d-e571-0109-e799-435511aae61b-13e4c863 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-b983a49d-4767-6b80-3997-caa78bbd2f8b-13e4c863, #w-node-_35a6000e-4745-82f9-240b-3e11f2581e05-13e4c863 {
    grid-area: span 1 / span 3 / span 1 / span 3;
}

#w-node-_83d6f05d-741e-b844-451e-a28484925089-13e4c864 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-da5bc5d1-5870-faa9-f42d-73310396d194-13e4c864, #w-node-_8402628b-b44e-9f04-36d7-49de7eaa169e-13e4c864, #w-node-_63d9265d-44e4-fe1b-fb89-961a3581021a-13e4c864, #w-node-cd193904-5227-c440-3b84-8eef6d854f4a-13e4c865, #w-node-ad7761c5-0720-1086-f378-34e757b0cffd-13e4c865 {
    grid-area: span 1 / span 3 / span 1 / span 3;
}

#w-node-c81625a2-c909-6fcf-246f-1f1f19b12839-13e4c865, #w-node-c81625a2-c909-6fcf-246f-1f1f19b1283a-13e4c865, #w-node-ad7761c5-0720-1086-f378-34e757b0cfff-13e4c865, #w-node-ad7761c5-0720-1086-f378-34e757b0d000-13e4c865, #w-node-_7027d086-beb1-cddc-5cdb-f269ad9343e3-13e4c865, #w-node-_7027d086-beb1-cddc-5cdb-f269ad9343e4-13e4c865, #w-node-_6405011f-2a7e-8ce7-7169-6f6b1ee055c5-13e4c865, #w-node-_6405011f-2a7e-8ce7-7169-6f6b1ee055c6-13e4c865, #w-node-_42cacc95-a55c-b1f0-3043-33031bbb9305-13e4c865, #w-node-_42cacc95-a55c-b1f0-3043-33031bbb9306-13e4c865 {
    grid-area: span 1 / span 1 / span 1 / span 1;
}

#w-node-_9f7e7334-9ae7-5911-fafe-fba726522020-13e4c865, #w-node-c2b652eb-a6a6-0a7e-9c10-9efbc862e0e4-13e4c865, #w-node-_34dcb27b-e423-35af-8dd0-6545b5f0bb05-13e4c865, #w-node-_32f9502b-72a1-33f0-a67d-4b6460ba94d7-13e4c865 {
    grid-area: span 1 / span 3 / span 1 / span 3;
}

@media screen and (min-width: 1280px) {
    #w-node-dc678c3f-8d8f-00ba-7466-144a35cd5f25-13e4c860 {
        justify-self: auto;
    }

    #w-node-b983a49d-4767-6b80-3997-caa78bbd2f88-13e4c863 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-b983a49d-4767-6b80-3997-caa78bbd2f8b-13e4c863 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-_35a6000e-4745-82f9-240b-3e11f2581e02-13e4c863 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-_35a6000e-4745-82f9-240b-3e11f2581e05-13e4c863 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-da5bc5d1-5870-faa9-f42d-73310396d191-13e4c864 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-da5bc5d1-5870-faa9-f42d-73310396d194-13e4c864 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-_8402628b-b44e-9f04-36d7-49de7eaa169b-13e4c864 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-_8402628b-b44e-9f04-36d7-49de7eaa169e-13e4c864 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-_63d9265d-44e4-fe1b-fb89-961a35810217-13e4c864 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-_63d9265d-44e4-fe1b-fb89-961a3581021a-13e4c864 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-cd193904-5227-c440-3b84-8eef6d854f47-13e4c865 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-cd193904-5227-c440-3b84-8eef6d854f4a-13e4c865 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-ad7761c5-0720-1086-f378-34e757b0cffa-13e4c865 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-ad7761c5-0720-1086-f378-34e757b0cffd-13e4c865 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-_9f7e7334-9ae7-5911-fafe-fba72652201d-13e4c865 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-_9f7e7334-9ae7-5911-fafe-fba726522020-13e4c865 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-c2b652eb-a6a6-0a7e-9c10-9efbc862e0e1-13e4c865 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-c2b652eb-a6a6-0a7e-9c10-9efbc862e0e4-13e4c865 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-_34dcb27b-e423-35af-8dd0-6545b5f0bb02-13e4c865 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-_34dcb27b-e423-35af-8dd0-6545b5f0bb05-13e4c865 {
        grid-area: 1 / 2 / 2 / 4;
    }

    #w-node-_32f9502b-72a1-33f0-a67d-4b6460ba94d4-13e4c865 {
        grid-area: span 1 / span 1 / span 1 / span 1;
    }

    #w-node-_32f9502b-72a1-33f0-a67d-4b6460ba94d7-13e4c865 {
        grid-area: 1 / 2 / 2 / 4;
    }
}

@media screen and (max-width: 991px) {
    #w-node-_11e2dc3d-d1e1-458c-44c2-5749cd8efbe5-cd8efba7 {
        grid-area: span 1 / span 3 / span 1 / span 3;
    }
}

@media screen and (max-width: 767px) {
    #w-node-_1d70a054-74c4-ff0a-a36b-00992d0f7cc6-13e4c860, #w-node-_9b908ccf-3f37-e264-b886-6d1f5dcd9ee9-13e4c860, #w-node-_14e8aef8-5200-041d-0346-c5a601590e52-13e4c860, #w-node-f2b417d0-d666-cff4-e74c-46a26350dc24-13e4c860, #w-node-_53334cf9-df90-50d4-4a1f-ea55c60f3cb4-13e4c860, #w-node-_13417cec-33ed-f2f6-e97d-5d543613c34b-13e4c860, #w-node-c80f83d6-ec0e-0e8c-6316-216cf8b31df1-13e4c860 {
        grid-area: span 1 / span 2 / span 1 / span 2;
    }
}


@font-face {
    font-family: 'Unicons';
    src: url('../fonts/unicons-line.woff2') format('woff2'), url('../fonts/unicons-line.woff') format('woff');
    font-weight: 400;
    font-style: normal;
    font-display: block;
}

@font-face {
    font-family: 'Space Grotesk';
    src: url('../fonts/SpaceGrotesk-SemiBold.woff2') format('woff2'), url('../fonts/SpaceGrotesk-SemiBold.woff') format('woff');
    font-weight: 600;
    font-style: normal;
    font-display: block;
}

@font-face {
    font-family: 'Space Grotesk';
    src: url('../fonts/SpaceGrotesk-Bold.woff2') format('woff2'), url('../fonts/SpaceGrotesk-Bold.woff') format('woff');
    font-weight: 700;
    font-style: normal;
    font-display: block;
}

@font-face {
    font-family: 'Space Grotesk';
    src: url('../fonts/SpaceGrotesk-Light.woff2') format('woff2'), url('../fonts/SpaceGrotesk-Light.woff') format('woff');
    font-weight: 300;
    font-style: normal;
    font-display: block;
}

@font-face {
    font-family: 'Space Grotesk';
    src: url('../fonts/SpaceGrotesk-Medium.woff2') format('woff2'), url('../fonts/SpaceGrotesk-Medium.woff') format('woff');
    font-weight: 500;
    font-style: normal;
    font-display: block;
}

@font-face {
    font-family: 'Space Grotesk';
    src: url('../fonts/SpaceGrotesk-Regular.woff2') format('woff2'), url('../fonts/SpaceGrotesk-Regular.woff') format('woff');
    font-weight: 400;
    font-style: normal;
    font-display: block;
}

@font-face {
    font-family: 'MATERIAL ICONS';
    src: url('../fonts/MaterialIconsRound-Regular.otf') format('opentype');
    font-weight: 400;
    font-style: normal;
    font-display: block;
}

.input-container {
    display: inline-block;
}

input.w-input[readonly] {
    display: inline-block;
    width: 85%; /* Adjust the width as needed */
    vertical-align: middle; /* Align the button vertically with the input */
    height: 40px;
    margin: 0;
}

.copy-btn {
    display: inline-block;
    vertical-align: middle; /* Align the button vertically with the input */
    margin-left: 10px; /* Add spacing between input and button */
    background-color: #eeeeee;
    color: black;
    border: 1px solid #cccccc;
    padding: 7px;
    text-align: center;
    text-decoration: none;
    font-size: 16px;
    cursor: pointer;
}

.copy-btn:hover {
    background-color: #45a049;
}
