{% extends "lotus/base.html" %}
{% load i18n %}

{% block header-title %}{% trans "Authors" %} | {{ django_blog_plus_site_name|default:"Blog" }}{% endblock header-title %}

{% block lotus_content %}
<div class="lotus-extras-blog-container">
    <div class="lotus-extras-page-header">
        <h1 class="lotus-extras-page-title">{% trans "Authors" %}</h1>
        <p class="lotus-extras-page-description">{% trans "Meet our writers" %}</p>
    </div>

    {% if author_list %}
    <div class="lotus-extras-articles-grid">
        {% for author in author_list %}
        <a href="{{ author.get_absolute_url }}" class="lotus-extras-article-card">
            <div class="lotus-extras-article-card-body">
                <h2 class="lotus-extras-article-card-title">{{ author.get_full_name|default:author.username }}</h2>
            </div>
        </a>
        {% endfor %}
    </div>
    {% else %}
    <p>{% trans "No authors found." %}</p>
    {% endif %}

    {% include "lotus/pagination.html" %}
</div>
{% endblock lotus_content %}
